/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998  Lionel ULMER
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __POSTGRES_H__
#define __POSTGRES_H__

#include "common.h"

DBConnector *register_PostgreSQL(GtkWidget **notebook_pane,
				 GtkWidget **notebook_label,
				 void (*error_dialog)(char *, char *),
				 DBConnector **ret_param,
				 void (*ok_callback)(GtkWidget *, gpointer)) ;

#endif  __POSTGRES_H__
